variables.h
changeset 1643 d38655053062
parent 1529 be4a2259d2ff
child 1688 787400219027
--- a/variables.h	Mon Apr 04 16:47:03 2005 +0000
+++ b/variables.h	Mon Apr 04 17:53:39 2005 +0000
@@ -195,7 +195,8 @@
 	/* New Path Finding */
 	bool new_pathfinding_all; /* Use the newest pathfinding algorithm for all */
 
-	uint32 npf_rail_firstred_penalty; /* The penalty for when the first signal is red */
+	uint32 npf_rail_firstred_penalty; /* The penalty for when the first signal is red (and it is not an exit or combo signal) */
+	uint32 npf_rail_firstred_exit_penalty; /* The penalty for when the first signal is red (and it is an exit or combo signal) */
 	uint32 npf_rail_lastred_penalty; /* The penalty for when the last signal is red */
 	uint32 npf_rail_station_penalty; /* The penalty for station tiles */
 	uint32 npf_rail_slope_penalty; /* The penalty for sloping upwards */